Skip to content

Commands & Permissions

Commands

Here is a list of all commands available in the Transport-Pipes plugin.

CommandDescriptionPermission
/tpipes tpsShows performance stats (ticks per second, amount of pipes/items currently ticking).transportpipes.tps
/tpipes settingsOpens the player-specific settings interface. Allows players to change their render distance and render system (Vanilla / Modelled).transportpipes.settings
/tpipes creativeOpens an inventory with access to every pipe without crafting. Only works in Creative Mode.transportpipes.creative

Permissions

General Permissions

PermissionDescriptionDefault
transportpipes.*Grants all Transport-Pipes permissions.
transportpipes.tpsAllows using /tpipes tps.OP only
transportpipes.creativeAllows using /tpipes creative.OP only
transportpipes.settingsAllows using /tpipes settings.Everyone

Crafting Permissions

These permissions control which pipes and tools a player can craft.

PermissionDescriptionDefault
transportpipes.craft.*Allows crafting all pipes and tools.Everyone
transportpipes.craft.coloredpipeAllows crafting Colored Pipes.Everyone
transportpipes.craft.extractionpipeAllows crafting Extraction Pipes.Everyone
transportpipes.craft.craftingpipeAllows crafting Crafting Pipes.Everyone
transportpipes.craft.goldenpipeAllows crafting Golden Pipes.Everyone
transportpipes.craft.icepipeAllows crafting Ice Pipes.Everyone
transportpipes.craft.ironpipeAllows crafting Iron Pipes.Everyone
transportpipes.craft.voidpipeAllows crafting Void Pipes.Everyone
transportpipes.craft.wrenchAllows crafting the Wrench.Everyone